#!/bin/sh
if [ -e /var/log/packages/32base* ]; then
cat <<EOF
***WARNING***
This package conflicts with the old 32base package. Please uninstall that package, and
use the new glibc32 package instead.
***WARNING***
EOF
fi
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.4 libbz2.so.1.0 )
( cd usr/bin/32 ; rm -rf cc )
( cd usr/bin/32 ; ln -sf gcc cc )
( cd usr/bin/32 ; rm -rf g++ )
( cd usr/bin/32 ; ln -sf gcc g++ )
( cd usr/bin/32 ; rm -rf libpng-config )
( cd usr/bin/32 ; ln -sf libpng12-config libpng-config )
( cd usr/lib ; rm -rf libgpg-error.so.0 )
( cd usr/lib ; ln -sf libgpg-error.so.0.5.0 libgpg-error.so.0 )
( cd usr/lib ; rm -rf libgnutls-extra.so.26 )
( cd usr/lib ; ln -sf libgnutls-extra.so.26.11.4 libgnutls-extra.so.26 )
( cd usr/lib ; rm -rf libmng.so )
( cd usr/lib ; ln -sf libmng.so.1.0.0 libmng.so )
( cd usr/lib ; rm -rf libjpeg.so.62 )
( cd usr/lib ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib ; rm -rf libpng.so )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so )
( cd usr/lib ; rm -rf libssl.so )
( cd usr/lib ; ln -sf libssl.so.0.9.8 libssl.so )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
( cd usr/lib ; rm -rf libcrypto.so )
( cd usr/lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so )
( cd usr/lib ; rm -rf libgpg-error.so )
( cd usr/lib ; ln -sf libgpg-error.so.0.5.0 libgpg-error.so )
( cd usr/lib ; rm -rf libz.so )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so )
( cd usr/lib ; rm -rf libgnutls-extra.so )
( cd usr/lib ; ln -sf libgnutls-extra.so.26.11.4 libgnutls-extra.so )
( cd usr/lib ; rm -rf libgcrypt.so.11 )
( cd usr/lib ; ln -sf libgcrypt.so.11.5.2 libgcrypt.so.11 )
( cd usr/lib ; rm -rf libgnutls.so )
( cd usr/lib ; ln -sf libgnutls.so.26.11.4 libgnutls.so )
( cd usr/lib ; rm -rf libgnutls-openssl.so.26 )
( cd usr/lib ; ln -sf libgnutls-openssl.so.26.11.4 libgnutls-openssl.so.26 )
( cd usr/lib ; rm -rf libgnutls-openssl.so )
( cd usr/lib ; ln -sf libgnutls-openssl.so.26.11.4 libgnutls-openssl.so )
( cd usr/lib ; rm -rf libgcrypt.so )
( cd usr/lib ; ln -sf libgcrypt.so.11.5.2 libgcrypt.so )
( cd usr/lib ; rm -rf libpng12.so )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so )
( cd usr/lib ; rm -rf libgnutlsxx.so )
( cd usr/lib ; ln -sf libgnutlsxx.so.26.11.4 libgnutlsxx.so )
( cd usr/lib ; rm -rf libpng.so.0 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.0 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.1.2.35 libpng.so.3 )
( cd usr/lib ; rm -rf libgnutlsxx.so.26 )
( cd usr/lib ; ln -sf libgnutlsxx.so.26.11.4 libgnutlsxx.so.26 )
( cd usr/lib ; rm -rf libgnutls.so.26 )
( cd usr/lib ; ln -sf libgnutls.so.26.11.4 libgnutls.so.26 )
( cd usr/lib ; rm -rf libjpeg.so )
( cd usr/lib ; ln -sf libjpeg.so.62 libjpeg.so )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.1.2.35 libpng12.so.0 )
( cd usr/lib ; rm -rf libmng.so.1 )
( cd usr/lib ; ln -sf libmng.so.1.0.0 libmng.so.1 )
( cd usr/lib ; rm -rf libpng.a )
( cd usr/lib ; ln -sf libpng12.a libpng.a )
( cd usr/lib ; rm -rf libbz2.so )
( cd usr/lib ; ln -sf ../../lib/./libbz2.so.1 libbz2.so )
